@@ -118,6 +118,7 @@ if (VERBOSE_LEVEL>7) fprintf(stdout,"%s:%i sopen_cfs_read started - %i bytes alr
 		}
 		hdr->AS.Header[count] = 0;
 		hdr->FLAG.OVERFLOWDETECTION = 0;
+		hdr->FILE.LittleEndian = 1;
 
 		/*
 			Implementation is based on the following reference:
@@ -349,6 +350,7 @@ else if (VERBOSE_LEVEL>7)
 				size_t pos = H1LEN + H2LEN*hdr->NS + (n+k+1)*36;
 				char   *desc = (char*)(hdr->AS.Header+pos+1);
 				uint16_t typ = leu16p(hdr->AS.Header+pos+22);
+				int  unitlen = (uint8_t)hdr->AS.Header[pos+24];
 				char   *unit = (char*)(hdr->AS.Header+pos+25);
 				uint16_t off = leu16p(hdr->AS.Header+pos+34);
 
@@ -372,7 +374,7 @@ else if (VERBOSE_LEVEL>7)
 					if ((Signal6_CodeDescLen < i) && (i < 256))
 						Signal6_CodeDescLen = i;
 				}
-				else if ((k==3) && (typ==6) && !strcmp(desc,"Start") && !strcmp(unit,"s"))
+				else if ((k==3) && (typ==6) && !strcmp(desc,"Start") && (unitlen>0) && !strncmp(unit,"s",unitlen))
 					tmp_event_pos = f;
 
 if (VERBOSE_LEVEL>7) 		{
@@ -420,8 +422,8 @@ if (VERBOSE_LEVEL>7) 		{
 
 				// uint32_t bi  = leu32p(pos);	// unused
 				uint32_t xspr = leu32p(pos+4);
-				float Cal    = lef32p(pos+8);
-				float Off    = lef32p(pos+12);
+				double Cal   = lef32p(pos+8);
+				double Off   = lef32p(pos+12);
 				double XCal  = lef32p(pos+16);
 				double XOff  = lef32p(pos+20);// unused
 				if (VERBOSE_LEVEL>7) fprintf(stdout,"%s (line %i): %i/%i %i/%i %f+%f change SPR:%i->%i, Cal:%f->%f, Off: %f->%f\n", \
@@ -435,8 +437,8 @@ if (VERBOSE_LEVEL>7) 		{
 					xspr0 = xspr;
 				else if (xspr>0)
 					xspr0 = lcm(xspr0,xspr);
-				else if (xspr==0)
-					if (VERBOSE_LEVEL>7) fprintf(stdout,"Warning : #%i of section %i contains %i samples \n", (int)k, (int)m, (int)xspr);
+				else if (xspr==0 && hc->OnOff)
+					if (VERBOSE_LEVEL>7) fprintf(stdout,"Warning : #%i of section %i contains %i samples (%d)\n", (int)k, (int)m, (int)xspr,  hc->OnOff);
 
 				if (m > 0) {
 					if ( (hc->Cal != Cal)
@@ -452,14 +454,19 @@ if (VERBOSE_LEVEL>7) 		{
 					case 6:
 					case 16:
 						hc->GDFTYP = 16; 	// float, single precision
+						hc->Cal = 1.0;
+						hc->Off = 0.0;
 						break;
 					case 7:
 					case 8:
 					case 17:
 						hc->GDFTYP = 17; 	// double
+						hc->Cal = 1.0;
+						hc->Off = 0.0;
 						break;
 					case 18:  	// quadruple
 					default: ;
+						fprintf(stderr, "ERROR: datatype %d in #%i of section %i not supported\n", hc->GDFTYP, (int)k, (int)m);
 					}
 				}
 				else {
@@ -531,7 +538,6 @@ if (VERBOSE_LEVEL>7) 		{
 			hdr->AS.length = 0;
 			char flag_firstchan = 1;
 			uint32_t xspr0 = 0;
-			float Cal, Off;
 			for (k = 0; k < hdr->NS; k++) {
 				uint8_t *pos = hdr->AS.Header + datapos + 30 + 24 * k;
 
@@ -540,10 +546,6 @@ if (VERBOSE_LEVEL>7) 		{
 				//uint32_t bi = leu32p(pos);	// unused
 				uint32_t xspr = leu32p(pos+4);
 				hc->SPR     = leu32p(pos+4);
-				hc->Cal     = lef32p(pos+8);
-				hc->Off     = lef32p(pos+12);
-				Cal         = lef32p(pos+8);
-				Off         = lef32p(pos+12);
 				double XCal = lef32p(pos+16);
 				double XOff = lef32p(pos+20);// unused
 
@@ -551,8 +553,8 @@ if (VERBOSE_LEVEL>7) 		{
 					xspr0 = xspr;
 				else if (xspr>0)
 					xspr0 = lcm(xspr0, xspr);
-				else if (xspr==0)
-					if (VERBOSE_LEVEL>7) fprintf(stdout,"Warning : #%i of section %i contains %i samples \n", (int)k, (int)m, (int)xspr);
+				else if (xspr==0 && hc->OnOff)
+					if (VERBOSE_LEVEL>7) fprintf(stdout,"%s line %d: Warning : #%i of section %i contains %i samples (OnOff=%d)\n", __FILE__, __LINE__, (int)k, (int)m, (int)xspr, hc->OnOff);
 
 				assert( (xspr==0) || ((xspr0 % xspr) == 0) );
 
@@ -591,6 +593,8 @@ if (VERBOSE_LEVEL>7) 		{
 					uint8_t *srcaddr = hdr->AS.Header + leu32p(hdr->AS.Header+datapos + 4) ;
 					//uint16_t byteSpace = leu16p(H2+44 + k*H2LEN);
 
+					double Cal         = lef32p(pos+8);
+					double Off         = lef32p(pos+12);
 					uint8_t  dataType  = H2[42 + k*H2LEN];
 					uint8_t  dataKind  = H2[43 + k*H2LEN];			// equidistant, Subsidiary or Matrix data
 					uint16_t stride    = leu16p(H2+44 + k*H2LEN);		// byteSpace
@@ -610,7 +614,7 @@ if (VERBOSE_LEVEL>7) 		{
 					}
 
 					size_t k2;
-					if (gdftyp == hc->GDFTYP) {
+					if (gdftyp == hc->GDFTYP && Cal==hc->Cal && Off==hc->Off) {
 					    for (k2 = 0; k2 < xspr0; k2++) {
 
 						uint8_t *ptr = srcaddr + memoffset + k2*stride;
