@@ -171,7 +171,7 @@ bool wxStfApp::OnInit(void)
 #endif
 #if defined(WITH_BIOSIG)
     m_biosigTemplate=new wxDocTemplate( docManager,
-                                     wxT("Biosig files"), wxT("*.dat;*.cfs;*.gdf;*.ibw;*.wcp"), wxT(""), wxT(""),
+                                     wxT("Biosig files"), wxT("*.abf;*.axgd;*.axgx;*.dat;*.cfs;*.gdf;*.ibw;*.wcp"), wxT(""), wxT(""),
                                      wxT("Biosig Document"), wxT("Biosig View"), CLASSINFO(wxStfDoc),
                                      CLASSINFO(wxStfView) );
 #endif
@@ -405,11 +405,9 @@ void wxStfApp::OnPeakcalcexecMsg(wxStfDoc* actDoc) {
         ErrorMsg(wxT("Uninitialized file in wxStfApp::OnPeakcalcexecMsg()"));
         return;
     }
-#ifdef __WXMAC__        
+
     wxStfView* actView = (wxStfView*)actDoc->GetFirstView();
-#else
-    wxStfView* actView = GetActiveView();
-#endif
+
     if (actView!=NULL) {
         wxStfGraph* pGraph = actView->GetGraph();
         if (pGraph != NULL)
@@ -867,11 +865,7 @@ wxStfChildFrame *wxStfApp::CreateChildFrame(wxDocument *doc, wxView *view)
     wxStfChildFrame *subframe = new wxStfChildFrame(
                                                     doc, view, 
                                                     wxStaticCast(GetTopWindow(), wxStfParentFrame), wxID_ANY, doc->GetTitle(),
-#ifdef __WXMAC__
                                                     wxDefaultPosition, wxDefaultSize,
-#else
-                                                    wxDefaultPosition, wxDefaultSize,
-#endif
                                                     wxDEFAULT_FRAME_STYLE |
                                                     // wxNO_FULL_REPAINT_ON_RESIZE |
                                                     wxWANTS_CHARS | wxMAXIMIZE
@@ -975,7 +969,7 @@ void wxStfApp::OnCursorSettings( wxCommandEvent& WXUNUSED(event) ) {
     wxStfDoc* actDoc=GetActiveDoc();
     if (CursorsDialog==NULL && actDoc!=NULL) {
         CursorsDialog=new wxStfCursorsDlg((wxStfParentFrame*)GetTopWindow(), actDoc);
-        CursorsDialog->Show();
+        CursorsDialog->ShowModal();
         CursorsDialog->SetActiveDoc(actDoc);
         //set CEdit controls to given values
         try {
@@ -994,7 +988,7 @@ void wxStfApp::OnCursorSettings( wxCommandEvent& WXUNUSED(event) ) {
     }
 
     if(CursorsDialog!=NULL && !CursorsDialog->IsShown() && actDoc!=NULL) {
-        CursorsDialog->Show();
+        CursorsDialog->ShowModal();
         CursorsDialog->SetActiveDoc(actDoc);
         //set CEdit controls to given values
         try {
