@@ -26,7 +26,7 @@
  */
 //! Event ids
 enum {
-    ID_TOOL_FIRST, // = wxID_HIGHEST+1, resulted in wrong events being fired
+    ID_TOOL_FIRST = wxID_HIGHEST+1, // resulted in wrong events being fired
     ID_TOOL_NEXT,
     ID_TOOL_PREVIOUS,
     ID_TOOL_LAST,
@@ -54,6 +54,7 @@ enum {
     ID_TOOL_CH1,
     ID_TOOL_CH2,
     ID_TOOL_SNAPSHOT,
+    ID_TOOL_ANNOTATION,
 
     ID_TOOL_SNAPSHOT_WMF,
     ID_TOOL_FITDECAY,
@@ -157,6 +158,11 @@ enum {
     ID_EVENT_ADDEVENT,
     ID_EVENT_EXTRACT,
     ID_EVENT_ERASE,
+    ID_ANNOTATION_ADDANNOTATION,
+    ID_ANNOTATION_REMOVEANNOTATION,
+    ID_ANNOTATION_ERASEALLANNOTATIONS,
+    ID_ANNOTATION_EXPORTANNOTATIONS,
+    ID_ANNOTATION_IMPORTANNOTATIONS,
     ID_COMBOTRACES,
     ID_SPINCTRLTRACES,
     ID_ZERO_INDEX,
@@ -205,7 +211,7 @@ enum {
 #endif
 #ifdef WITH_PYTHON
 #if PY_MAJOR_VERSION >= 3
-  #include <wxPython/sip.h>
+  #include "../sip.h"
   #include <wxPython/wxpy_api.h>
 #else
   #include <wx/wxPython/wxPython.h>
