@@ -95,6 +95,13 @@ EVT_PAINT( wxStfGraph::OnPaint )
 #endif
 END_EVENT_TABLE()
 
+struct AnnotationLine {
+    wxPoint start;
+    wxPoint end;
+};
+
+std::vector<AnnotationLine> annotationLines;
+
 // Define a constructor for my canvas
 wxStfGraph::wxStfGraph(wxView *v, wxStfChildFrame *frame, const wxPoint& pos, const wxSize& size, long style):
     wxScrolledWindow(frame, wxID_ANY, pos, size, style),pFrame(frame),
@@ -134,7 +141,7 @@ wxStfGraph::wxStfGraph(wxView *v, wxStfChildFrame *frame, const wxPoint& pos, co
     measPen(*wxBLACK,1,wxPENSTYLE_DOT),
     eventPen(*wxBLUE,2,wxPENSTYLE_SOLID),
 #ifdef WITH_PSLOPE
-    PSlopePen(wxColor(30,144,255), 1, wxDOT), // Dotted bright blue line
+    PSlopePen(wxColor(30,144,255), 1, wxPENSTYLE_DOT), // Dotted bright blue line
 #endif
     standardPrintPen(*wxBLACK,printSizePen1,wxPENSTYLE_SOLID), //Solid black line
     standardPrintPen2(*wxRED,printSizePen1,wxPENSTYLE_SOLID), //Solid red line
@@ -165,7 +172,8 @@ wxStfGraph::wxStfGraph(wxView *v, wxStfChildFrame *frame, const wxPoint& pos, co
     lastLDown(0,0),
     yzoombg(),
     m_zoomContext( new wxMenu ),
-    m_eventContext( new wxMenu )
+    m_eventContext( new wxMenu ),
+    m_annotationContext( new wxMenu )
 {
     m_zoomContext->Append( ID_ZOOMHV, wxT("Expand zoom window horizontally && vertically") );
     m_zoomContext->Append( ID_ZOOMH, wxT("Expand zoom window horizontally") );
@@ -175,6 +183,12 @@ wxStfGraph::wxStfGraph(wxView *v, wxStfChildFrame *frame, const wxPoint& pos, co
     m_eventContext->Append( ID_EVENT_ERASE, wxT("Erase all events") );
     m_eventContext->Append( ID_EVENT_EXTRACT, wxT("Extract selected events") );
 
+    m_annotationContext->Append( ID_ANNOTATION_ADDANNOTATION, wxT("Add an annotation that starts here") );
+    m_annotationContext->Append( ID_ANNOTATION_REMOVEANNOTATION, wxT("Remove this annotation") );
+    m_annotationContext->Append( ID_ANNOTATION_ERASEALLANNOTATIONS, wxT("Erase all annotations") );
+    m_annotationContext->Append( ID_ANNOTATION_EXPORTANNOTATIONS, wxT("Export the annotations") );
+    m_annotationContext->Append( ID_ANNOTATION_IMPORTANNOTATIONS, wxT("Import all annotations") );
+
     SetBackgroundColour(*wxWHITE);
     view = (wxStfView*)v;
     wxString perspective=wxGetApp().wxGetProfileString(wxT("Settings"),wxT("Windows"),wxT(""));
@@ -499,8 +513,10 @@ void wxStfGraph::PlotGimmicks(wxDC& DC) {
     try {
         stf::SectionAttributes sec_attr = Doc()->GetCurrentSectionAttributes();
         if (!sec_attr.eventList.empty()) {
-            PlotEvents(DC);
+             PlotEvents(DC);
         }
+        PlotAnnotations(DC);
+
         if (!sec_attr.pyMarkers.empty()) {
             DC.SetPen(eventPen);
             for (c_marker_it it = sec_attr.pyMarkers.begin(); it != sec_attr.pyMarkers.end(); ++it) {
@@ -516,6 +532,29 @@ void wxStfGraph::PlotGimmicks(wxDC& DC) {
 
 }
 
+void wxStfGraph::PlotAnnotations(wxDC& dc) {
+
+    std::vector<Annotation> annotations = Doc()->at(Doc()->GetCurChIndex())[Doc()->GetCurSecIndex()].GetAnnotationList();
+    annotationLines.clear();
+    for (auto& ann : annotations) {
+
+        // position to x coordinate
+        int x = xFormat(ann.GetAnnotationPosition());
+        // Choose a y position (top of graph)
+        int y = GetClientSize().y;
+
+        // Draw a marker
+        dc.SetPen(*wxRED_PEN);
+        wxPoint startPoint(x, 0);
+        wxPoint endPoint(x, y);
+        dc.DrawLine(startPoint, endPoint);
+
+        AnnotationLine line = {.start = startPoint, .end = endPoint};
+        annotationLines.push_back(line);
+    }
+}
+
+
 void wxStfGraph::PlotEvents(wxDC& DC) {
     const int MAX_EVENTS_PLOT = 200;
 
@@ -546,6 +585,7 @@ void wxStfGraph::PlotEvents(wxDC& DC) {
     if (isPrinted) WindowRect=wxRect(printRect);
     int right=WindowRect.width;
     int nevents_plot = 0;
+
     for (event_it it2 = sec_attr.eventList.begin(); it2 != sec_attr.eventList.end(); ++it2) {
         nevents_plot += (xFormat(it2->GetEventStartIndex()) < right &&
                          xFormat(it2->GetEventStartIndex()) > 0);
@@ -1266,14 +1306,22 @@ void wxStfGraph::RButtonDown(wxMouseEvent& event) {
     case stf::event_cursor:
         try {
             if (!Doc()->GetCurrentSectionAttributes().eventList.empty()) {
-                // store the position that has been clicked:
-                eventPos = stf::round( ((double)point.x - (double)SPX())/XZ() );
-                PopupMenu(m_eventContext.get());
+            // store the position that has been clicked:
+            eventPos = stf::round( ((double)point.x - (double)SPX())/XZ() );
+            PopupMenu(m_eventContext.get());
             } else {
                 wxGetApp().ErrorMsg(wxT("No events have been detected yet"));
             }
         } catch (const std::out_of_range& e) {
 
+        }
+        break;
+    case stf::annotation_cursor:
+        try{
+            eventPos = stf::round( ((double)point.x - (double)SPX())/XZ() );
+            PopupMenu(m_annotationContext.get());
+        }catch(const std::out_of_range& e){
+
         }
         break;
 #ifdef WITH_PSLOPE
@@ -1459,6 +1507,10 @@ void wxStfGraph::OnKeyDown(wxKeyEvent& event) {
      case 108:
          ParentFrame()->SetMouseQual(stf::latency_cursor);
          return;
+     case 78:  // n
+     case 110:
+         ParentFrame()->SetMouseQual(stf::annotation_cursor);
+         return;
      case WXK_RETURN:    //Enter or Return
      {
          wxGetApp().OnPeakcalcexecMsg();
@@ -2011,81 +2063,73 @@ void wxStfGraph::Fittowindow(bool refresh)
         wxGetApp().ErrorMsg(wxT("Array of size zero in wxGraph::Fittowindow()"));
         return;
     }
-#if (__cplusplus < 201103)
-    Vector_double::const_iterator max_el = std::max_element(Doc()->cursec().get().begin(), Doc()->cursec().get().end());
-    Vector_double::const_iterator min_el = std::min_element(Doc()->cursec().get().begin(), Doc()->cursec().get().end());
-#else
-    Vector_double::const_iterator max_el = std::max(Doc()->cursec().get().begin(), Doc()->cursec().get().end());
-    Vector_double::const_iterator min_el = std::min(Doc()->cursec().get().begin(), Doc()->cursec().get().end());
-#endif
-    double min = *min_el;
-    if (min>1.0e12)  min= 1.0e12;
-    if (min<-1.0e12) min=-1.0e12;
-    double max = *max_el;
-    if (max>1.0e12)  max= 1.0e12;
-    if (max<-1.0e12) max=-1.0e12;
-    wxRect WindowRect(GetRect());
-    switch (ParentFrame()->GetZoomQual())
-    {	//Depending on the zoom radio buttons (Mouse field)
-    //in the (trace navigator) control box
-    case stf::zoomboth:
-        if(!(Doc()->size()>1))
-            return;
 
-        //Fit to window Ch2
+    const auto& sec = Doc()->cursec().get();
+    if (sec.empty()) return;
+
+    auto max_el = std::max_element(sec.begin(), sec.end());
+    auto min_el = std::min_element(sec.begin(), sec.end());
+
+    double min = std::clamp(*min_el, -1.0e12, 1.0e12);
+    double max = std::clamp(*max_el, -1.0e12, 1.0e12);
+
+    wxSize size = GetClientSize();
+    if (size.GetWidth() <= 0 || points == 0)
+        return;
+
+    wxRect WindowRect(0, 0, size.GetWidth(), size.GetHeight());
+
+    switch (ParentFrame()->GetZoomQual()) {
+    case stf::zoomboth:
+        if (Doc()->size() <= 1) return;
         FitToWindowSecCh(false);
-        //Fit to window Ch1
-        XZW()=(double)WindowRect.width /points;
-        SPXW()=0;
+        XZW() = static_cast<double>(WindowRect.width) / points;
+        SPXW() = 0;
         FittorectY(Doc()->GetYZoomW(Doc()->GetCurChIndex()), WindowRect, min, max, screen_part);
         break;
     case stf::zoomch2:
-        //ErrorMsg if no second channel available
-        if(!(Doc()->size()>1))
-            return;
-
-        //Fit to window Ch2
+        if (Doc()->size() <= 1) return;
         FitToWindowSecCh(false);
         break;
+
     default:
-        //ErrorMsg if no second channel available
-        //			Invalidate();
-        //Fit to window Ch1
-        XZW()=(double)WindowRect.width /points;
-        SPXW()=0;
+        XZW() = static_cast<double>(WindowRect.width) / points;
+        SPXW() = 0;
         FittorectY(Doc()->GetYZoomW(Doc()->GetCurChIndex()), WindowRect, min, max, screen_part);
         break;
     }
-    if (refresh) Refresh();
+
+    if (refresh) {
+        Refresh();
+        Update(); // Ensure actual paint occurs
+    }
 }
 
 void wxStfGraph::FitToWindowSecCh(bool refresh)
 {
+    if (Doc()->size() <= 1) return;
 
-    if (Doc()->size()>1) {
-        //Get coordinates of the main window
-        wxRect WindowRect(GetRect());
+    wxSize size = GetClientSize();
+    if (size.GetWidth() <= 0 || size.GetHeight() <= 0) return;
 
-        const double screen_part=0.5; //part of the window to be filled
-        std::size_t secCh=Doc()->GetSecChIndex();
-    #undef min
-    #undef max
-#if (__cplusplus < 201103)
-        Vector_double::const_iterator max_el = std::max_element(Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().begin(),
-                                                                Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().end());
-        Vector_double::const_iterator min_el = std::min_element(Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().begin(),
-                                                                Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().end());
-#else
-        Vector_double::const_iterator max_el = std::max(Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().begin(),
-                                                               Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().end());
-        Vector_double::const_iterator min_el = std::min(Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().begin(),
-                                                                Doc()->get()[secCh][Doc()->GetCurSecIndex()].get().end());
-#endif
+    wxRect WindowRect(0, 0, size.GetWidth(), size.GetHeight());
+    const double screen_part = 0.5;
 
-        double min=*min_el;
-        double max=*max_el;
-        FittorectY(Doc()->GetYZoomW(Doc()->GetSecChIndex()), WindowRect, min, max, screen_part);
-        if (refresh) Refresh();
+    std::size_t secCh = Doc()->GetSecChIndex();
+    auto& secData = Doc()->get()[secCh][Doc()->GetCurSecIndex()].get();
+    if (secData.empty()) return;
+
+    auto max_el = std::max_element(secData.begin(), secData.end());
+    auto min_el = std::min_element(secData.begin(), secData.end());
+
+    double min = std::clamp(*min_el, -1.0e12, 1.0e12);
+    double max = std::clamp(*max_el, -1.0e12, 1.0e12);
+
+    FittorectY(Doc()->GetYZoomW(secCh), WindowRect, min, max, screen_part);
+
+    if (refresh) {
+        Refresh();
+        Update(); // forces redraw in wx 3.x
     }
 }	//End FitToWindowSecCh()
 
